@@ -1,3 +1,4 @@
+import importlib
 from typing import Type, TypeVar
 
 from injector import inject
@@ -18,13 +19,19 @@ class Dispatcher(IScoped):
     def __init__(self, service_provider: ServiceProvider):
         self.service_provider = service_provider
 
-    def find_handler(self, type, handler_type: Type[T]) -> T:
-        for handler_class in handler_type.__subclasses__():
-            result = handler_type[type] == handler_class.__orig_bases__[0]
+    def find_handler(self, cq, handler_type: Type[T]) -> T:
+        try:
+            importlib.import_module(cq.__module__ + 'Handler')
+        except Exception as ex:
+            pass
+        subclasses = handler_type.__subclasses__()
+        for handler_class in subclasses:
+            result = handler_type[cq.__class__] == handler_class.__orig_bases__[0]
             if result:
                 instance = self.service_provider.get(handler_class)
                 return instance
 
+
     def dispatch(self, cq: CommandQueryBase[T]) -> T:
         if isinstance(cq, IQuery):
             handler_type = IQueryHandler
@@ -32,7 +39,7 @@ class Dispatcher(IScoped):
             handler_type = ICommandHandler
         else:
             raise Exception("Command or query not found")
-        handler = self.find_handler(cq.__class__, handler_type)
+        handler = self.find_handler(cq, handler_type)
         if handler is None:
             raise Exception("Handler not founded")
         return handler.handle(cq)
