@@ -2,6 +2,7 @@ import queue
 import threading
 
 from pdip.logging.loggers.console import ConsoleLogger
+
 from .channel_queue import ChannelQueue
 from ..domain import TaskMessage
 
@@ -13,15 +14,24 @@ class EventListener(threading.Thread):
                  logger: ConsoleLogger,
                  *args, **kwargs
                  ):
+        super().__init__(*args, **kwargs)
         self.logger = logger
         self.subscribers = subscribers
         self.channel = channel
-        super().__init__(*args, **kwargs)
+        self._stop_event = threading.Event()
+
+    def stop(self):
+        self._stop_event.set()
+
+    def stopped(self):
+        return self._stop_event.is_set()
 
     def run(self):
         while True:
             try:
                 task: TaskMessage = self.channel.get()
+                if task is None:
+                    return
                 if task.event in self.subscribers.keys():
                     for callback in self.subscribers[task.event]:
                         callback(**task.kwargs)
@@ -32,5 +42,8 @@ class EventListener(threading.Thread):
                 self.channel.done()
             except queue.Empty:
                 return
+            except Exception as e:
+                self.logger.error('error')
+                return
             finally:
                 pass
